biom.table.Table
================

.. currentmodule:: biom.table

.. autoclass:: Table

   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         Table.__eq__
         Table.__format__
         Table.__getitem__
         Table.__init__
         Table.__iter__
         Table.__ne__
         Table.__new__
         Table.__reduce__
         Table.__reduce_ex__
         Table.__repr__
         Table.__sizeof__
         Table.__str__
         Table.__subclasshook__
         Table._axis_to_num
         Table._cast_metadata
         Table._conv_to_self_type
         Table._data_equality
         Table._extract_data_from_tsv
         Table._get_col
         Table._get_row
         Table._get_sparse_data
         Table._index
         Table._index_ids
         Table._intersect_id_order
         Table._invert_axis
         Table._iter_obs
         Table._iter_samp
         Table._to_dense
         Table._to_sparse
         Table._union_id_order
         Table.add_group_metadata
         Table.add_metadata
         Table.collapse
         Table.copy
         Table.data
         Table.delimited_self
         Table.descriptive_equality
         Table.exists
         Table.filter
         Table.from_hdf5
         Table.from_json
         Table.from_tsv
         Table.get_table_density
         Table.get_value_by_ids
         Table.group_metadata
         Table.ids
         Table.index
         Table.is_empty
         Table.iter
         Table.iter_data
         Table.iter_pairwise
         Table.length
         Table.max
         Table.merge
         Table.metadata
         Table.min
         Table.nonzero
         Table.nonzero_counts
         Table.norm
         Table.pa
         Table.partition
         Table.reduce
         Table.sort
         Table.sort_order
         Table.subsample
         Table.sum
         Table.to_hdf5
         Table.to_json
         Table.to_tsv
         Table.transform
         Table.transpose
         Table.update_ids



   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         Table.dtype
         Table.matrix_data
         Table.nnz
         Table.shape

